<?php
/**
 * The template for displaying Comments
 *
 * The area of the page that contains both current comments
 * and the comment form. The actual display of comments is
 * handled by a callback to lana_comment() which is
 * located in the lana-functions.php file.
 *
 * @package Theme-Vision
 * @subpackage Lana
 * @since 1.0.0
 */

/*
 * If the current post is protected by a password and
 * the visitor has not yet entered the password we will
 * return early without loading the comments.
 */
if ( post_password_required() )
	return; ?>

<div id="comments" class="comments-container block">

	<?php // You can start editing here -- including this comment! ?>

	<?php if ( have_comments() ) : ?>
		<h2 class="comments-title">
			<?php
				printf( 
					_n( '<span>%1$s</span> Comment', '<span>%1$s</span> Comments', get_comments_number(), 'lana' ),
					number_format_i18n( get_comments_number() ), 
					'<span>' . get_the_title() . '</span>' ); ?></h2>

		<ol class="comment-list lana-box">
			<?php wp_list_comments( array( 'callback' => 'lana_comment', 'style' => 'ol' ) ); ?>
		</ol><!-- .commentlist -->

		<?php if ( get_comment_pages_count() > 1 && get_option( 'page_comments' ) ) : // are there comments to navigate through ?>
		<nav id="comment-nav-below" class="navigation" role="navigation">
			<h1 class="assistive-text section-heading"><?php _e( 'Comment navigation', 'lana' ); ?></h1>
			<div class="nav-previous"><?php previous_comments_link( __( '&larr; Older Comments', 'lana' ) ); ?></div>
			<div class="nav-next"><?php next_comments_link( __( 'Newer Comments &rarr;', 'lana' ) ); ?></div>
		</nav>
		<?php endif; // check for comment navigation ?>

		<?php
		/* If there are no comments and comments are closed, let's leave a note.
		 * But we only want the note on posts and pages that had comments in the first place.
		 */
		if ( ! comments_open() && get_comments_number() ) : ?>
		<p class="nocomments"><?php _e( 'Comments are closed.' , 'lana' ); ?></p>
		<?php endif; ?>

	<?php endif; // have_comments() ?>

	<?php 
	$commenter 	= wp_get_current_commenter();
	$req 		= get_option( 'require_name_email' );
	$aria_req 	= ( $req ? " aria-required='true'" : '' );
	
	$comment_args = array
	( 
		'class_submit' => 'btn-large full-width',
		'title_reply' => __( 'Leave a Comment', 'lana' ),
		'fields' => apply_filters(
		  'comment_form_default_fields', array
			(
				'author' =>	'<div class="form-group row"><div class="col-xs-4">' .
							'<label for="author">' . __( 'Name', 'lana' ) . '*</label> ' .
							'<input id="author" name="author" type="text" value="' . esc_attr( $commenter['comment_author'] ) . '" class="input-text full-width"' . $aria_req . ' /></div>',   
				
				'email'  => '<div class="col-xs-4">' . '<label for="email">' . __( 'Email', 'lana' ) . '*</label> ' .
							'<input id="email" name="email" type="text" value="' . esc_attr(  $commenter['comment_author_email'] ) . '" class="input-text full-width"' . $aria_req . ' /></div>',
				
				'url'    => '<div class="col-xs-4">' . '<label for="url">' . __( 'Website', 'lana' ) . '</label>' .
							'<input id="url" name="url" type="text" value="' . esc_url( $commenter['comment_author_url'] ) . '" class="input-text full-width" /></div></div>',
			) 
		),
		'comment_field' => 	'<div class="form-group">' .
							'<label for="comment">' . __( 'Comment', 'lana' ) . '*</label>' .
							'<textarea id="comment" name="comment" cols="45" rows="8" aria-required="true" class="input-text full-width"></textarea></div>',
							
		'logged_in_as' 	=> '<div class="form-group logged-in-as">' .
		sprintf
		(	'%s <a href="%s">%s</a>. <a href="%s" title="%s">%s</a>',
			__('Logged in as', 'lana'), admin_url( 'profile.php' ), $user_identity, wp_logout_url( apply_filters( 'the_permalink', get_permalink( ) ) ),
			__('Log out of this account', 'lana'), __('Log out?', 'lana')
		) . '</div>',
		'comment_notes_after' => '<div class="form-group" style="margin-top: 15px; margin-bottom: 15px;">' .
		sprintf
		(	'%s <abbr title="HyperText Markup Language">HTML</abbr> %s: %s',
			__( 'You may use these', 'lana' ), __( 'tags and attributes', 'lana' ), '<code>' . allowed_tags() . '</code>'
		) . '</div>',
	);
	
	comment_form( $comment_args ); ?>

</div><!-- #comments .comments-area -->